we04abf1 = function(funct, bound, e=NA, mfun=NA) {
  ## R code to call e04abf
  ## funct    - Function being minimised
  ## bound[1] - a (NA = default value used)
  ## bound[2] - b (NA = default value used)
  ## e[1]     - e1 (NA = default value used)
  ## e[2]     - e2 (NA = default value used)
  ## mfun     - max_fun (NA = default value used)

  ## This example shows calling the C code using the function f directly
  if (!is.loaded("we04abf")) {
    stop("External routine we04abf is not loaded")
  }
  
  ## Call NAG routine
  .Call("we04abf",funct,as.double(bound),as.double(e),as.integer(mfun),new.env())
}

we04abf2 = function(funct, bound, e=rep(NA,2), mfun=NA) {
  ## R code to call e04abf
  ## funct    - Function being minimised
  ## bound[1] - a (NA = default value used)
  ## bound[2] - b (NA = default value used)
  ## e[1]     - e1 (NA = default value used)
  ## e[2]     - e2 (NA = default value used)
  ## mfun     - max_fun (NA = default value used)

  ## This example shows calling the C code using the body of a function rather than
  ## the function itself

  if (!is.loaded("we04abf")) {
    stop("External routine we04abf is not loaded")
  }
  
  i.funct = function(x) {
    ## Wrap the user function and make sure it returns a valid result
    x = funct(x)

    ## We could check for a numeric result here, but that would not deallocate
    ## memory allocated in the C code
    ##    if(!is.numeric(x)) stop("Need a numeric result")

    as.double(x)
  }

  ## Call NAG routinec
  .Call("we04abf",body(i.funct),as.double(bound),as.double(e),as.integer(mfun),new.env())
}


## Example of using the function
funct = function(y) {
  sin(y) / y
}
we04abf1(funct, c(3.5,5.0))
we04abf2(funct, c(3.5,5.0))
